@@ -3,8 +3,6 @@ import signal
 import subprocess
 import sys
 import time
-import unittest
-import uvloop
 
 from uvloop import _testbase as tb
 
@@ -395,23 +393,6 @@ class Test_UV_Signals(_TestSignal, tb.UVTestCase):
 
             self.loop.add_signal_handler(signal.SIGCHLD, lambda *a: None)
 
-    @unittest.skipIf(sys.version_info[:3] >= (3, 8, 0),
-                     'in 3.8 a ThreadedChildWatcher is used '
-                     '(does not rely on SIGCHLD)')
-    def test_asyncio_add_watcher_SIGCHLD_nop(self):
-        asyncio.set_event_loop_policy(asyncio.DefaultEventLoopPolicy())
-        asyncio.get_event_loop_policy().get_child_watcher()
-
-        try:
-            loop = uvloop.new_event_loop()
-            with self.assertWarnsRegex(
-                    RuntimeWarning,
-                    "asyncio is trying to install its ChildWatcher"):
-                asyncio.set_event_loop(loop)
-        finally:
-            asyncio.set_event_loop(None)
-            loop.close()
-
 
 class Test_AIO_Signals(_TestSignal, tb.AIOTestCase):
     NEW_LOOP = 'asyncio.new_event_loop()'
